@@ -11,7 +11,7 @@ check_prereq btrfs-convert
 for bs in 1024 2048; do
 	default_mke2fs="mke2fs -t ext4 -b $bs"
 	convert_test_preamble '' "unsupported block size $bs" 16k "$default_mke2fs"
-	convert_test_prep_fs $default_mke2fs
+	convert_test_prep_fs ext4 $default_mke2fs
 
 	run_check $SUDO_HELPER dd if=/dev/zero of="$TEST_MNT/file" bs=1M \
 		count=1 seek=1024 > /dev/null 2>&1
